
# Slot: has decreased amount




URI: [biolink:has_decreased_amount](https://w3id.org/biolink/vocab/has_decreased_amount)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Narrow Mappings:** | | CL:has_low_plasma_membrane_amount |

